@@ -120,7 +120,7 @@ class Adumo:
         transaction_id, amount, cvv = self.decode_md(md)
 
         try:
-            self._authenticate(pares, md)
+            self._authenticate(pares, transaction_id)
         except Exception:
             return {"status": FAILED, "transaction_id": transaction_id}
 
@@ -134,9 +134,7 @@ class Adumo:
         url = f"{API_URL}product/authentication/v1/tds/authenticate/"
         request = {"md": md, "payload": pares}
         result = httpx.post(url, json=request, headers=self.headers)
-
         response_dict = self._process_response(result)
-
         logger.info(
             f"[CreditCard] Authenticate 3ds response {response_dict.get('errorNo')} - "
             f"{response_dict.get('errorMsg')}"
@@ -145,7 +143,6 @@ class Adumo:
     def _authorise_and_settle(self, ccv, transaction_id: str, amount: str):
 
         request = {"transactionId": transaction_id, "amount": amount, "cvv": ccv}
-
         result = httpx.post(
             f"{API_URL}products/payments/v1/card/authorise",
             json=request,
