@@ -13,4 +13,4 @@ APPLICATION_ID = env(
 )
 MERCHANT_UID = env("ADUMO_MERCHANT_UID", default="9BA5008C-08EE-4286-A349-54AF91A621B0")
 
-DEFAULT_IP_ADDRESS = env("ADUMO_ORIGIN_IP")
+DEFAULT_IP_ADDRESS = env("ADUMO_ORIGIN_IP", default="192.168.0.1")
